pivot_unchecked

Function pivot_unchecked 

pub fn pivot_unchecked(g: &mut impl GraphLike, v0: V, v1: V)
Apply pivoting to a pair of vertices

This is the version that deletes both vertices, so it is effectively a generalised version of the strong complementarity rule.