#[non_exhaustive]pub enum JsonError {
InvalidPhase {
phase: String,
},
InvalidNodePhase {
name: String,
phase: String,
},
SerdeError(Error),
}Expand description
An error that can occur when decoding a json graph.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidPhase
Found an invalid phase value.
InvalidNodePhase
Found an invalid phase value in a node definition.
SerdeError(Error)
Some other serde error.